@@ -125,7 +125,7 @@ class CompileRest(PageCompiler):
             'math_output': 'mathjax /assets/js/mathjax.js',
             'template': default_template_path,
             'language_code': LEGAL_VALUES['DOCUTILS_LOCALES'].get(LocaleBorg().current_lang, 'en'),
-            'doctitle_xform': not self.site.config.get('USE_REST_DOCINFO_METADATA'),
+            'doctitle_xform': self.site.config.get('USE_REST_DOCINFO_METADATA'),
         }
 
         from nikola import shortcodes as sc
@@ -189,6 +189,9 @@ class CompileRest(PageCompiler):
             self.config_dependencies.append(plugin_info.name)
             plugin_info.plugin_object.short_help = plugin_info.description
 
+        if not site.debug:
+            self.logger.level = logbook.base.WARNING
+
 
 def get_observer(settings):
     """Return an observer for the docutils Reporter."""
